Method: Gosu::Window#initialize

Defined in:
rdoc/gosu.rb

#initialize(width, height, options = {}) ⇒ Window #initialize(width, height, fullscreen, update_interval = 16.666666) ⇒ Window

Creates a new window with the requested size.

Resizable fullscreen windows always use the full desktop resolution. Windows that are larger than the desktop resolution will be shrunk.

Parameters:

  • width (Integer)

    the desired window width.

  • height (Integer)

    the desired window height.

  • options (Hash)

Options Hash (options):

  • :fullscreen (true, false) — default: false

    whether to present the window in fullscreen mode.

  • :resizable (true, false) — default: false

    whether the window can be resized by the user. Not useful if the window is either fullscreen or borderless.

  • :borderless (true, false) — default: false

    whether the window should hide all its window chrome. Does not affect fullscreen windows.

  • :update_interval (Float) — default: 16.666666

    the interval between frames, in milliseconds.



847
# File 'rdoc/gosu.rb', line 847

def initialize(width, height, options); end