Method: Gosu::Sample#play

Defined in:
rdoc/gosu.rb

#play(volume = 1, speed = 1, looping = false) ⇒ Channel

Plays the sample without panning.

Parameters:

  • volume (Float) (defaults to: 1)
  • speed (Float) (defaults to: 1)
  • looping (true, false) (defaults to: false)

    whether the sample should play in a loop. If you pass true, be sure to store the return value of this method so that you can later stop the looping sound.

Returns:

See Also:



580
# File 'rdoc/gosu.rb', line 580

def play(volume=1, speed=1, looping=false); end