Class: Gosu::Song

Inherits:
Object
  • Object
show all
Defined in:
rdoc/gosu.rb

Overview

Songs are less flexible than samples in that only one can be played at a time, with no panning or speed control.

See Also:

Class Attribute Summary collapse

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(filename) ⇒ Song #initialize(window, filename) ⇒ Song

Loads a song from a file.

(Passing a Window reference is not necessary anymore, please use the first overload instead.)



675
# File 'rdoc/gosu.rb', line 675

def initialize(filename); end

Class Attribute Details

.current_songGosu::Song? (readonly)

Returns the song currently being played (even if it's paused), or nil if no song is playing.



659
660
661
# File 'rdoc/gosu.rb', line 659

def current_song
  @current_song
end

Instance Attribute Details

#volumeFloat



664
665
666
# File 'rdoc/gosu.rb', line 664

def volume
  @volume
end

Instance Method Details

#pausevoid

This method returns an undefined value.

Pauses playback of the song. The current song is unchanged.



692
# File 'rdoc/gosu.rb', line 692

def pause; end

#paused?true, false

Returns true if this song is the current song and playback is paused.



697
# File 'rdoc/gosu.rb', line 697

def paused?; end

#play(looping = false) ⇒ void

This method returns an undefined value.

Starts or resumes playback of the song.

If another song is currently playing, it will be stopped and this song will be set as the current song.

If looping is false, the current song will be set to nil when this song finishes.



686
# File 'rdoc/gosu.rb', line 686

def play(looping=false); end

#playing?true, false



707
# File 'rdoc/gosu.rb', line 707

def playing?; end

#stopvoid

This method returns an undefined value.

Stops playback if this song is the current song. The current song is set to nil.



703
# File 'rdoc/gosu.rb', line 703

def stop; end