Method: Gosu::Window#close

Defined in:
rdoc/gosu.rb

#closebool

This method is called whenever the user tries to close the window, e.g. by clicking the [x] button in the window’s title bar. If you do not want the window to close immediately, you should override this method and call the #close! when needed.

Returns:

  • (bool)


913
# File 'rdoc/gosu.rb', line 913

def close; end