Method: Gosu::Window#height

Defined in:
rdoc/gosu.rb

#heightInteger

The window’s height, in pixels. This only counts the drawable area and does not include any borders or decorations added by the window manager.



801
802
803
# File 'rdoc/gosu.rb', line 801

def height
  @height
end