Method: Gosu::Window#tick

Defined in:
rdoc/gosu.rb

#ticktrue, false

EXPERIMENTAL - MAY DISAPPEAR WITHOUT WARNING.

Performs a single step in the main loop. This can be useful for integrating Gosu with other libraries that have their own main loop, e.g. Ruby/Tk.

See: www.libgosu.org/cgi-bin/mwf/topic_show.pl?tid=1218

If you find a good way to use #tick, please let us know on the forum and we can make this a part of Gosu’s stable interface. Thank you!

Returns:

  • (true, false)

    whether the Gosu::Window should still be shown after this tick



867
# File 'rdoc/gosu.rb', line 867

def tick; end