Method: Gosu::Window#initialize
- Defined in:
- rdoc/gosu.rb
#initialize(width, height, options = {}) ⇒ Window #initialize(width, height, fullscreen, update_interval = 16.666666) ⇒ Window
Creates a new window with the requested size.
Resizable fullscreen windows always use the full desktop resolution. Windows that are larger than the desktop resolution will be shrunk.
847 |
# File 'rdoc/gosu.rb', line 847 def initialize(width, height, ); end |