Method: Gosu::Channel#stop
- Defined in:
- rdoc/gosu.rb
#stop ⇒ void
This method returns an undefined value.
Stops playback of this sample instance. After calling this method, the sample instance is useless and can be discarded.
Calling stop after the sample has finished is harmless and has no effect.
624 |
# File 'rdoc/gosu.rb', line 624 def stop; end |