Method: Gosu::Image.from_text
- Defined in:
- rdoc/gosu.rb
.from_text(text, line_height, options = {}) ⇒ Gosu::Image .from_text(window, text, font_name, line_height) ⇒ Gosu::Image .from_text(window, text, font_name, line_height, line_spacing, width, align) ⇒ Gosu::Image
Note:
The text is always rendered in white. To draw it in a different color, use the color parameter of #draw, et al.
Creates a reusable image from one or more lines of text.
(Passing a Window reference is not necessary anymore, please use the first overload from now on.)
420 |
# File 'rdoc/gosu.rb', line 420 def self.from_text(text, line_height, = {}); end |