Called when a file is dropped onto the window.
Parameters:
the filename of the dropped file. When multiple files are dropped, this method will be called several times.
944
# File 'rdoc/gosu.rb', line 944 def drop(filename); end