Method: Gosu::Window#width
- Defined in:
- rdoc/gosu.rb
#width ⇒ Integer
The window’s width, in pixels. This only counts the drawable area and does not include any borders or decorations added by the window manager.
795 796 797 |
# File 'rdoc/gosu.rb', line 795 def width @width end |